# ProjectSelectModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str, none_type** |  | [optional] 
**is_favorite** | **bool, none_type** |  | [optional] 
**is_deleted** | **bool, none_type** |  | [optional] 
**min_test_cases_count** | **int, none_type** |  | [optional] 
**max_test_cases_count** | **int, none_type** |  | [optional] 
**min_checklists_count** | **int, none_type** |  | [optional] 
**max_checklists_count** | **int, none_type** |  | [optional] 
**min_shared_steps_count** | **int, none_type** |  | [optional] 
**max_shared_steps_count** | **int, none_type** |  | [optional] 
**min_autotests_count** | **int, none_type** |  | [optional] 
**max_autotests_count** | **int, none_type** |  | [optional] 
**global_ids** | **[int], none_type** |  | [optional] 
**created_by_ids** | **[str], none_type** |  | [optional] 
**created_from** | **datetime, none_type** |  | [optional] 
**created_to** | **datetime, none_type** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


